==> ejc-jlcost-impl-3.0.0-20240523.032345-68-sources.jar: com/ejianc/business/jlcost/finance/bean/LoadApplyEntity.java <==
package com.ejianc.business.jlcost.finance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 资金管理-借款申请
 * 
 * @author generator
 * 
 */
 @TableName("ejc_finance_load_apply")
public class LoadApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 申请编号
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="apply_mny")
    private BigDecimal applyMny; // 申请金额
    @TableField(value="backed_mny")
    private BigDecimal backedMny; // 已退还金额
    @TableField(value="cumulative_mny")
    private BigDecimal cumulativeMny; // 已报销金额
    @TableField(value="apply_employee_id")
    private Long applyEmployeeId; // 申请人
    @TableField(value="apply_employee_name")
    private String applyEmployeeName; // 申请人名称
    @TableField(value="dept_id")
    private Long deptId; // 申请部门
    @TableField(value="dept_name")
    private String deptName; // 申请部门名称
    @TableField(value="apply_date")
    private Date applyDate; // 申请时间
    @TableField(value="predict_use_time")
    private Date predictUseTime; // 预计用款日期
    @TableField(value="account_name")
    private String accountName; // 账户名
    @TableField(value="bank_account")
    private String bankAccount; // 银行账号
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="receive_way")
    private Long receiveWay; // 收款方式
    @TableField(value="receive_way_name")
    private String receiveWayName; // 收款方式名称
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public BigDecimal getApplyMny() {
        return applyMny;
    }

    public void setApplyMny(BigDecimal applyMny) {
        this.applyMny = applyMny;
    }
    public BigDecimal getBackedMny() {
        return backedMny;
    }

    public void setBackedMny(BigDecimal backedMny) {
        this.backedMny = backedMny;
    }
    public BigDecimal getCumulativeMny() {
        return cumulativeMny;
    }

    public void setCumulativeMny(BigDecimal cumulativeMny) {
        this.cumulativeMny = cumulativeMny;
    }
    public Long getApplyEmployeeId() {
        return applyEmployeeId;
    }

    public void setApplyEmployeeId(Long applyEmployeeId) {
        this.applyEmployeeId = applyEmployeeId;
    }
    public String getApplyEmployeeName() {
        return applyEmployeeName;
    }

    public void setApplyEmployeeName(String applyEmployeeName) {
        this.applyEmployeeName = applyEmployeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public Date getPredictUseTime() {
        return predictUseTime;
    }

    public void setPredictUseTime(Date predictUseTime) {
        this.predictUseTime = predictUseTime;
    }
    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getReceiveWay() {
        return receiveWay;
    }

    public void setReceiveWay(Long receiveWay) {
        this.receiveWay = receiveWay;
    }
    public String getReceiveWayName() {
        return receiveWayName;
    }

    public void setReceiveWayName(String receiveWayName) {
        this.receiveWayName = receiveWayName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-jlcost-impl-3.0.0-20240613.020842-102-sources.jar: com/ejianc/business/jlcost/finance/bean/LoadApplyEntity.java <==
package com.ejianc.business.jlcost.finance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 资金管理-借款申请
 * 
 * @author generator
 * 
 */
 @TableName("ejc_finance_load_apply")
public class LoadApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 申请编号
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="apply_mny")
    private BigDecimal applyMny; // 申请金额
    @TableField(value="backed_mny")
    private BigDecimal backedMny; // 已退还金额
    @TableField(value="cumulative_mny")
    private BigDecimal cumulativeMny; // 已报销金额
    @TableField(value="apply_employee_id")
    private Long applyEmployeeId; // 申请人
    @TableField(value="apply_employee_name")
    private String applyEmployeeName; // 申请人名称
    @TableField(value="dept_id")
    private Long deptId; // 申请部门
    @TableField(value="dept_name")
    private String deptName; // 申请部门名称
    @TableField(value="apply_date")
    private Date applyDate; // 申请时间
    @TableField(value="predict_use_time")
    private Date predictUseTime; // 预计用款日期
    @TableField(value="account_name")
    private String accountName; // 账户名
    @TableField(value="bank_account")
    private String bankAccount; // 银行账号
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="receive_way")
    private Long receiveWay; // 收款方式
    @TableField(value="receive_way_name")
    private String receiveWayName; // 收款方式名称
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value="status")
    private Integer status; // 借款状态（1:申请中 2:使用中 3:已结束）

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public BigDecimal getApplyMny() {
        return applyMny;
    }

    public void setApplyMny(BigDecimal applyMny) {
        this.applyMny = applyMny;
    }
    public BigDecimal getBackedMny() {
        return backedMny;
    }

    public void setBackedMny(BigDecimal backedMny) {
        this.backedMny = backedMny;
    }
    public BigDecimal getCumulativeMny() {
        return cumulativeMny;
    }

    public void setCumulativeMny(BigDecimal cumulativeMny) {
        this.cumulativeMny = cumulativeMny;
    }
    public Long getApplyEmployeeId() {
        return applyEmployeeId;
    }

    public void setApplyEmployeeId(Long applyEmployeeId) {
        this.applyEmployeeId = applyEmployeeId;
    }
    public String getApplyEmployeeName() {
        return applyEmployeeName;
    }

    public void setApplyEmployeeName(String applyEmployeeName) {
        this.applyEmployeeName = applyEmployeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public Date getPredictUseTime() {
        return predictUseTime;
    }

    public void setPredictUseTime(Date predictUseTime) {
        this.predictUseTime = predictUseTime;
    }
    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getReceiveWay() {
        return receiveWay;
    }

    public void setReceiveWay(Long receiveWay) {
        this.receiveWay = receiveWay;
    }
    public String getReceiveWayName() {
        return receiveWayName;
    }

    public void setReceiveWayName(String receiveWayName) {
        this.receiveWayName = receiveWayName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
